/*
	<linux/compat/module.h>

	some compatibility macros for linux/module.h

	(C) Dmitry Fedorov, fedorov@inp.nsk.su, 2000

	$Id: module.h,v 1.3 2000/08/13 08:37:11 fedorov Exp $
*/

/*
Usage:

#include <linux/compat/module.h>

[...]

#define COMPAT_SYMTAB_NAME my_symbol_table_name
#include <linux/compat/symtab_begin.h>

EXPORT_SYMBOL(symbol1)        EXPORT_SYMBOL_END

[...]

EXPORT_SYMBOL(symbolN)        EXPORT_SYMBOL_END

#include <linux/compat/symtab_end.h>

[...]

int xx_init(void)
{
	[...]

	if ( (rc=register_chrdev(major, name, &xx_fops)) < 0 )
		{ ... }

	[...]

# ifdef COMPAT_REGISTER_SYMTAB_NEEDED
	if ( (rc=register_symtab( &xx_syms )) != 0 )
	{
		printk(KERN_ERR "register_symtab() error, errno=%d\n", -rc);
		unregister_chrdev(major, name);
		return rc;
	}
# endif

	[...]
}

*/



#ifndef  _LINUX_COMPAT_MODULE_H
# define _LINUX_COMPAT_MODULE_H

# include <linux/compat/version.h>
# include <linux/module.h>

# if LINUX_VERSION_CODE < KERNEL_VERSION(2,1,18)
#  define MODULE_AUTHOR(name)
#  define MODULE_DESCRIPTION(desc)
#  define MODULE_SUPPORTED_DEVICE(name)
#  define MODULE_PARM(var,type)
#  define MODULE_PARM_DESC(var,desc)

#  define EXPORT_SYMBOL(symbol) X(symbol)
#  define EXPORT_SYMBOL_NOVERS(symbol) XNOVERS(symbol)
#  define EXPORT_SYMBOL_END ,
#  define COMPAT_REGISTER_SYMTAB_NEEDED
# else
#  define EXPORT_SYMBOL_END ;
#  define register_symtab(symtab)
#  undef  COMPAT_REGISTER_SYMTAB_NEEDED
# endif

#endif	/* _LINUX_COMPAT_MODULE_H */

