/*
	<linux/compat/system.h>

	some compatibility macros for asm/system.h

	compiled from kernel sources by Dmitry Fedorov, fedorov@inp.nsk.su

	$Id: system.h,v 1.10 2000/10/05 08:27:53 fedorov Exp $
*/

#ifndef  _LINUX_COMPAT_SYSTEM_H
# define _LINUX_COMPAT_SYSTEM_H

# include <linux/compat/version.h>
# include <asm/system.h>



# if LINUX_VERSION_CODE < KERNEL_VERSION(2,1,0)
#  define rmb() mb()
#  define wmb() mb()

#  define __cli() cli()
#  define __sti() sti()

#  define __save_flags(x) save_flags(x)
#  define __restore_flags(x) restore_flags(x)
# endif



/* __xchg() was buggy! */
# if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,0)
#  define xchg_compat(ptr,v) \
	({ register __typeof__(*(ptr)) volatile __t = xchg((ptr),(v)); __t; })
# else
#  define xchg_compat(ptr,v) xchg((ptr),(v))
# endif



# if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,0)
/* __xchg() was buggy twice!
it seems that set_mb() on i386 should use xchg()
but __xchg() has no volatile attribute at pointer (2nd argument)
and compiler generates error on __xchg(value, &currnet->state, ...)
FIX ME: can mb() used in set_mb() ? :) */
#  define  set_mb(var, value) do { (var) = (value);  mb(); } while (0)
#  define set_wmb(var, value) do { (var) = (value); wmb(); } while (0)
# endif



#endif	/* _LINUX_COMPAT_SYSTEM_H */

