/*
	wait interrupts from IRQ driver by signal.

	(C) Dmitry A. Fedorov, fedorov@inp.nsk.su
	Copying-policy: LGPL

	$Id: irqsig.c,v 1.13 1999/10/21 07:32:40 fedorov Exp $

	tab size = 4
*/

#include <stdio.h>
#include <errno.h>
#include <fcntl.h>		/* open */
#include <signal.h>
#include <unistd.h>
#include <sched.h>		/* sched_yield */
#include <string.h>		/* strerror    */
#include "../irq.h"

static size_t sigcount=0;
static pid_t pid=0;

static void sighandler(int signum)
{
	signum=signum;	/* unused */

#if 0
	printf("process %d sighandler: signal %d, count %u\n",
		pid, signum, sigcount);
#endif

	sigcount++;
}

int main(int ac, char* av[])
{
	int fd,rc;
	struct sigaction sa;
	pid=getpid();

	if (ac<2)
	{
		printf("Usage: %s irqdevice\n", av[0]);
		return 1;
	}

	fd=open(av[1], O_RDWR);
	if (fd==-1)
	{
		perror(av[1]);
		return 2;
	}

	sigemptyset(&sa.sa_mask);
	sa.sa_handler=sighandler;
	sa.sa_flags=SA_RESTART;

	rc=sigaction(SIGUSR2, &sa, NULL);
	if (rc!=0)
	{
		perror("sigaction");
		return 2;
	}

	rc=irq_request(fd,SIGUSR2,
#if 1
		IRQ_SHARED
#else
		0
#endif
		);
	if (rc!=0)
	{
		perror("irq_request()");
		return 2;
	}

	for (;;)
	{
		pause();
		printf("\rprocess %d pause(): ", pid);
		if (errno==EINTR)
			printf("signal received, sigcount=%u", sigcount);
		else
			printf(strerror(errno));
		printf("\n");
		fflush(stdout);
		sched_yield();
	}

	return 0;
}

